@@ -15,8 +15,6 @@ import glob
 import logging
 
 
-
-
 class LLMSingleton:
     _instance = None
     _model = None
@@ -27,8 +25,7 @@ class LLMSingleton:
 
         if not selected_config:
             raise ValueError(f"No configuration found for the model: {model_id}")
-        if not isinstance(selected_config, LLMConfigItem):
-            selected_config = LLMConfigItem(**selected_config)
+        
         LLMSingleton._model = model_id
 
         # Typesafe for None values inside the config.
@@ -495,7 +492,7 @@ def generate_config_prompt_template_file(prompt_data_path, config_prompt_templat
 def generate_config_prompt_givens_file(prompt_data_path, config_prompt_givens_name, artefact_to_mark=None):
     config_prompt_givens_path = os.path.join(prompt_data_path, config_prompt_givens_name)
     config = ConfigManager.get_config()
-    dir_list = ["ara"] + [ext.source_dir for ext in config.ext_code_dirs] + [config.doc_dir] + [config.glossary_dir]
+    dir_list = ["ara"] + [ext['source_dir'] for ext in config.ext_code_dirs] + [config.doc_dir] + [config.glossary_dir]
 
     print(f"used {dir_list} for prompt givens file listing")
     generate_markdown_listing(dir_list, config.ara_prompt_given_list_includes, config_prompt_givens_path)
